Documentation
¶
Index ¶
- type Client
- type ClientService
- type SolanaTokenSecurityUsingGETForbidden
- type SolanaTokenSecurityUsingGETNotFound
- type SolanaTokenSecurityUsingGETOK
- type SolanaTokenSecurityUsingGETParams
- func NewSolanaTokenSecurityUsingGETParams() *SolanaTokenSecurityUsingGETParams
- func NewSolanaTokenSecurityUsingGETParamsWithContext(ctx context.Context) *SolanaTokenSecurityUsingGETParams
- func NewSolanaTokenSecurityUsingGETParamsWithHTTPClient(client *http.Client) *SolanaTokenSecurityUsingGETParams
- func NewSolanaTokenSecurityUsingGETParamsWithTimeout(timeout time.Duration) *SolanaTokenSecurityUsingGETParams
- func (o *SolanaTokenSecurityUsingGETParams) SetAuthorization(authorization *string)
- func (o *SolanaTokenSecurityUsingGETParams) SetContext(ctx context.Context)
- func (o *SolanaTokenSecurityUsingGETParams) SetContractAddresses(contractAddresses string)
- func (o *SolanaTokenSecurityUsingGETParams) SetHTTPClient(client *http.Client)
- func (o *SolanaTokenSecurityUsingGETParams) SetTimeout(timeout time.Duration)
- func (o *SolanaTokenSecurityUsingGETParams) WithAuthorization(authorization *string) *SolanaTokenSecurityUsingGETParams
- func (o *SolanaTokenSecurityUsingGETParams) WithContext(ctx context.Context) *SolanaTokenSecurityUsingGETParams
- func (o *SolanaTokenSecurityUsingGETParams) WithContractAddresses(contractAddresses string) *SolanaTokenSecurityUsingGETParams
- func (o *SolanaTokenSecurityUsingGETParams) WithHTTPClient(client *http.Client) *SolanaTokenSecurityUsingGETParams
- func (o *SolanaTokenSecurityUsingGETParams) WithTimeout(timeout time.Duration) *SolanaTokenSecurityUsingGETParams
- func (o *SolanaTokenSecurityUsingGETParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type SolanaTokenSecurityUsingGETReader
- type SolanaTokenSecurityUsingGETUnauthorized
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for token security api for solana beta API
func (*Client) SetTransport ¶
func (a *Client) SetTransport(transport runtime.ClientTransport)
SetTransport changes the transport on the client
func (*Client) SolanaTokenSecurityUsingGET ¶
func (a *Client) SolanaTokenSecurityUsingGET(params *SolanaTokenSecurityUsingGETParams) (*SolanaTokenSecurityUsingGETOK, error)
SolanaTokenSecurityUsingGET gets token s security and risk data
type ClientService ¶
type ClientService interface {
SolanaTokenSecurityUsingGET(params *SolanaTokenSecurityUsingGETParams) (*SolanaTokenSecurityUsingGETOK, error)
SetTransport(transport runtime.ClientTransport)
}
ClientService is the interface for Client methods
func New ¶
func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService
New creates a new token security api for solana beta API client.
type SolanaTokenSecurityUsingGETForbidden ¶
type SolanaTokenSecurityUsingGETForbidden struct {
}
SolanaTokenSecurityUsingGETForbidden handles this case with default header values.
Forbidden
func NewSolanaTokenSecurityUsingGETForbidden ¶
func NewSolanaTokenSecurityUsingGETForbidden() *SolanaTokenSecurityUsingGETForbidden
NewSolanaTokenSecurityUsingGETForbidden creates a SolanaTokenSecurityUsingGETForbidden with default headers values
func (*SolanaTokenSecurityUsingGETForbidden) Error ¶
func (o *SolanaTokenSecurityUsingGETForbidden) Error() string
type SolanaTokenSecurityUsingGETNotFound ¶
type SolanaTokenSecurityUsingGETNotFound struct {
}
SolanaTokenSecurityUsingGETNotFound handles this case with default header values.
Not Found
func NewSolanaTokenSecurityUsingGETNotFound ¶
func NewSolanaTokenSecurityUsingGETNotFound() *SolanaTokenSecurityUsingGETNotFound
NewSolanaTokenSecurityUsingGETNotFound creates a SolanaTokenSecurityUsingGETNotFound with default headers values
func (*SolanaTokenSecurityUsingGETNotFound) Error ¶
func (o *SolanaTokenSecurityUsingGETNotFound) Error() string
type SolanaTokenSecurityUsingGETOK ¶
type SolanaTokenSecurityUsingGETOK struct {
Payload *models.ResponseWrapperSolanaTokenSecurity
}
SolanaTokenSecurityUsingGETOK handles this case with default header values.
OK
func NewSolanaTokenSecurityUsingGETOK ¶
func NewSolanaTokenSecurityUsingGETOK() *SolanaTokenSecurityUsingGETOK
NewSolanaTokenSecurityUsingGETOK creates a SolanaTokenSecurityUsingGETOK with default headers values
func (*SolanaTokenSecurityUsingGETOK) Error ¶
func (o *SolanaTokenSecurityUsingGETOK) Error() string
func (*SolanaTokenSecurityUsingGETOK) GetPayload ¶
func (o *SolanaTokenSecurityUsingGETOK) GetPayload() *models.ResponseWrapperSolanaTokenSecurity
type SolanaTokenSecurityUsingGETParams ¶
type SolanaTokenSecurityUsingGETParams struct {
/*Authorization
Authorization token in the format: Bearer <token> (e.g., Bearer eyJsZXZlbCI6NSwiYXBwTmFtZSI6ImF2cyIsImFwcEtleSI6IjFaW...)
*/
Authorization *string
/*ContractAddresses
The contract address of solana tokens.
*/
ContractAddresses string
Context context.Context
HTTPClient *http.Client
// contains filtered or unexported fields
}
SolanaTokenSecurityUsingGETParams contains all the parameters to send to the API endpoint for the solana token security using g e t operation typically these are written to a http.Request
func NewSolanaTokenSecurityUsingGETParams ¶
func NewSolanaTokenSecurityUsingGETParams() *SolanaTokenSecurityUsingGETParams
NewSolanaTokenSecurityUsingGETParams creates a new SolanaTokenSecurityUsingGETParams object with the default values initialized.
func NewSolanaTokenSecurityUsingGETParamsWithContext ¶
func NewSolanaTokenSecurityUsingGETParamsWithContext(ctx context.Context) *SolanaTokenSecurityUsingGETParams
NewSolanaTokenSecurityUsingGETParamsWithContext creates a new SolanaTokenSecurityUsingGETParams object with the default values initialized, and the ability to set a context for a request
func NewSolanaTokenSecurityUsingGETParamsWithHTTPClient ¶
func NewSolanaTokenSecurityUsingGETParamsWithHTTPClient(client *http.Client) *SolanaTokenSecurityUsingGETParams
NewSolanaTokenSecurityUsingGETParamsWithHTTPClient creates a new SolanaTokenSecurityUsingGETParams object with the default values initialized, and the ability to set a custom HTTPClient for a request
func NewSolanaTokenSecurityUsingGETParamsWithTimeout ¶
func NewSolanaTokenSecurityUsingGETParamsWithTimeout(timeout time.Duration) *SolanaTokenSecurityUsingGETParams
NewSolanaTokenSecurityUsingGETParamsWithTimeout creates a new SolanaTokenSecurityUsingGETParams object with the default values initialized, and the ability to set a timeout on a request
func (*SolanaTokenSecurityUsingGETParams) SetAuthorization ¶
func (o *SolanaTokenSecurityUsingGETParams) SetAuthorization(authorization *string)
SetAuthorization adds the authorization to the solana token security using g e t params
func (*SolanaTokenSecurityUsingGETParams) SetContext ¶
func (o *SolanaTokenSecurityUsingGETParams) SetContext(ctx context.Context)
SetContext adds the context to the solana token security using g e t params
func (*SolanaTokenSecurityUsingGETParams) SetContractAddresses ¶
func (o *SolanaTokenSecurityUsingGETParams) SetContractAddresses(contractAddresses string)
SetContractAddresses adds the contractAddresses to the solana token security using g e t params
func (*SolanaTokenSecurityUsingGETParams) SetHTTPClient ¶
func (o *SolanaTokenSecurityUsingGETParams) SetHTTPClient(client *http.Client)
SetHTTPClient adds the HTTPClient to the solana token security using g e t params
func (*SolanaTokenSecurityUsingGETParams) SetTimeout ¶
func (o *SolanaTokenSecurityUsingGETParams) SetTimeout(timeout time.Duration)
SetTimeout adds the timeout to the solana token security using g e t params
func (*SolanaTokenSecurityUsingGETParams) WithAuthorization ¶
func (o *SolanaTokenSecurityUsingGETParams) WithAuthorization(authorization *string) *SolanaTokenSecurityUsingGETParams
WithAuthorization adds the authorization to the solana token security using g e t params
func (*SolanaTokenSecurityUsingGETParams) WithContext ¶
func (o *SolanaTokenSecurityUsingGETParams) WithContext(ctx context.Context) *SolanaTokenSecurityUsingGETParams
WithContext adds the context to the solana token security using g e t params
func (*SolanaTokenSecurityUsingGETParams) WithContractAddresses ¶
func (o *SolanaTokenSecurityUsingGETParams) WithContractAddresses(contractAddresses string) *SolanaTokenSecurityUsingGETParams
WithContractAddresses adds the contractAddresses to the solana token security using g e t params
func (*SolanaTokenSecurityUsingGETParams) WithHTTPClient ¶
func (o *SolanaTokenSecurityUsingGETParams) WithHTTPClient(client *http.Client) *SolanaTokenSecurityUsingGETParams
WithHTTPClient adds the HTTPClient to the solana token security using g e t params
func (*SolanaTokenSecurityUsingGETParams) WithTimeout ¶
func (o *SolanaTokenSecurityUsingGETParams) WithTimeout(timeout time.Duration) *SolanaTokenSecurityUsingGETParams
WithTimeout adds the timeout to the solana token security using g e t params
func (*SolanaTokenSecurityUsingGETParams) WriteToRequest ¶
func (o *SolanaTokenSecurityUsingGETParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type SolanaTokenSecurityUsingGETReader ¶
type SolanaTokenSecurityUsingGETReader struct {
// contains filtered or unexported fields
}
SolanaTokenSecurityUsingGETReader is a Reader for the SolanaTokenSecurityUsingGET structure.
func (*SolanaTokenSecurityUsingGETReader) ReadResponse ¶
func (o *SolanaTokenSecurityUsingGETReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the received o.
type SolanaTokenSecurityUsingGETUnauthorized ¶
type SolanaTokenSecurityUsingGETUnauthorized struct {
}
SolanaTokenSecurityUsingGETUnauthorized handles this case with default header values.
Unauthorized
func NewSolanaTokenSecurityUsingGETUnauthorized ¶
func NewSolanaTokenSecurityUsingGETUnauthorized() *SolanaTokenSecurityUsingGETUnauthorized
NewSolanaTokenSecurityUsingGETUnauthorized creates a SolanaTokenSecurityUsingGETUnauthorized with default headers values
func (*SolanaTokenSecurityUsingGETUnauthorized) Error ¶
func (o *SolanaTokenSecurityUsingGETUnauthorized) Error() string